def print_signature() -> None:
    print("""-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA512

This is a signature package.
-----BEGIN PGP SIGNATURE-----

iHUEARYKAB0WIQTu3enDu4rKxAP4uLZq1HqAflJe8QUCYvq4owAKCRBq1HqAflJe
8c8CAP9CsgWD9Vf3CzEYlonVm6r+gM0LZ/sQmyS8FqZbxBbjBwD/Z+QEh6T2yYas
c8MEh1X4vzd98C6G2An7RkE9PP1SxAo=
=AVDl
-----END PGP SIGNATURE-----
""")
